API docs for “spamfighter.core.message.attribute.AttributeDomain”

# Class s.c.m.a.AttributeDomain(object):

Part of spamfighter.core.message.attribute View Source View In Hierarchy

Known subclasses: spamfighter.core.message.attribute.IntAttributeDomain, spamfighter.core.message.attribute.IPAttributeDomain, spamfighter.core.message.attribute.TextAttributeDomain

Домент (тип атрибута).

Instance Variables | _name | имя атрибута (type: `str` )

Method | __init__ | Конструктор.
Method | name | Получить имя атрибута.
Method | serialize | Получить сериализованное значение атрибута.
Method | deserialize | Десериализовать значение в атрибут.
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented

def __init__(self, name): (source)
Конструктор.

Parameters | name | имя атрибута (type: `str` )

def name(self): (source)
Получить имя атрибута.

Returns | имя атрибута (type: `str` )

def serialize(self, attribute): (source)
overridden in spamfighter.core.message.attribute.IntAttributeDomain, spamfighter.core.message.attribute.IPAttributeDomain, spamfighter.core.message.attribute.TextAttributeDomain
Получить сериализованное значение атрибута.

Parameters | attribute | атрибут (type: `IAttribute` )
Returns | сериализованное значение атрибута

def deserialize(self, value): (source)
overridden in spamfighter.core.message.attribute.IntAttributeDomain, spamfighter.core.message.attribute.IPAttributeDomain, spamfighter.core.message.attribute.TextAttributeDomain
Десериализовать значение в атрибут.

Parameters | value | сериализованное значение
Returns | атрибут (type: `IAttribute` )

def __eq__(self, other): (source)
Undocumented
def __repr__(self): (source)
Undocumented